============================================
``psyclone.tests.psyir.backend.opencl_test``
============================================

.. automodule:: psyclone.tests.psyir.backend.opencl_test

   .. contents::
      :local:

.. currentmodule:: psyclone.tests.psyir.backend.opencl_test
